==> haskell-hscolour-1.23-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hscolour/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.23
id: hscolour-1.23-12df95f4b94c13684d4abc3c2e6b8387
key: hscol_D9eX1LEa8SaE1RFFjW0myg
license: GPL
copyright: 2003-2015 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ANSI
    Language.Haskell.HsColour.Anchors Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hscolour-1.23
library-dirs: /usr/lib/ghc-7.10.3/site-local/hscolour-1.23
data-dir: /usr/share/arm-linux-ghc-7.10.3/hscolour-1.23
hs-libraries: HShscolour-1.23-D9eX1LEa8SaE1RFFjW0myg
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hscolour-1.24-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hscolour/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hscolour
version: 1.24
id: hscolour-1.24-b1fe788d8499aec980e06c0cdcf38b18
key: hscol_EoUpEnZrIZsFshJcZ46fQA
license: GPL
copyright: 2003-2016 Malcolm Wallace; 2006 Bjorn Bringert
maintainer: Malcolm Wallace
homepage: http://code.haskell.org/~malcolm/hscolour/
synopsis: Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.
category: Language
author: Malcolm Wallace
exposed: True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ANSI
    Language.Haskell.HsColour.Anchors Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hscolour-1.24
library-dirs: /usr/lib/ghc-7.10.3/site-local/hscolour-1.24
data-dir: /usr/share/arm-linux-ghc-7.10.3/hscolour-1.24
hs-libraries: HShscolour-1.24-EoUpEnZrIZsFshJcZ46fQA
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
haddock-interfaces: /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html: /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
